django-eros
===========

.. image:: https://secure.travis-ci.org/thoas/django-eros.png?branch=master
    :alt: Build Status
    :target: http://travis-ci.org/thoas/django-eros

Standalone Django application to like any content types you want and transform link.

Compatibility
-------------

This library is compatible with:

- python2.6, django1.4
- python2.6, django1.5
- python2.6, django1.6
- python2.7, django1.4
- python2.7, django1.5
- python2.7, django1.6
- python3.3, django1.5
- python3.3, django1.6

Thanks to `oleiade <https://github.com/oleiade>`_ for this application name.
